Crate kcr_storageos_com

Crate kcr_storageos_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the storageos.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

storageos.com/v1

  • StorageOSCluster

Modules

v1